<?php
/*
 * Plugin Name: Options for Twenty Seventeen Premium
 * Version: 1.1.7
 * Plugin URI: https://webd.uk/options-for-twenty-seventeen/
 * Description: Adds even more options to modify the default Wordpress theme Twenty Seventeen
 * Author: Webd Ltd
 * Author URI: https://webd.uk
 */



if (!defined('ABSPATH')) {
    exit('This isn\'t the page you\'re looking for. Move along, move along.');
}



if (!class_exists('options_for_twenty_seventeen_premium_class')) {

	class options_for_twenty_seventeen_premium_class {

        public static $version = '1.1.7';

		function __construct() {

            add_action('customize_register', array($this, 'ofts_customize_register'), 999);
            add_action('wp_head' , array($this, 'ofts_header_output'));
            add_action('load-post.php', array($this, 'ofts_theme_options_metabox_setup'));
            add_action('load-post-new.php', array($this, 'ofts_theme_options_metabox_setup'));

            if (oftsPremium::request_permission(true) == true) {

                if (get_theme_mod('front_page_sections')) {

                    add_filter('twentyseventeen_front_page_sections', array($this, 'ofts_front_page_sections'));

                }

                if (get_option('show_on_front') == 'page') {

                    add_filter('nav_menu_meta_box_object', array($this, 'ofts_front_page_sections_add_menu_meta_box'), 10, 1);
                    add_action('get_footer', array($this, 'ofts_inject_ids_to_front_page_sections'));

                }

                if (get_theme_mod('footer_sidebars')) {

                    add_action('widgets_init', array($this, 'ofts_footer_sidebars_init'));

                }

                add_filter('post_thumbnail_html', array($this, 'ofts_hide_featured_image'), 10, 5);
                add_action('get_footer', array($this, 'ofts_home_page_panels'), 10, 5);

            }

            if (is_admin()) {

                add_filter('pre_set_site_transient_update_plugins', 'oftsPremium::check_plugin_update');
                add_filter('plugins_api', 'oftsPremium::get_plugin_information', 10, 3);
                add_filter('after_plugin_row_' . plugin_basename(__FILE__), 'oftsPremium::activate_purchase_js', 10, 3);
                add_action('wp_ajax_ofts_activate_purchase', 'oftsPremium::activate_purchase');
                add_action('admin_notices', 'oftsPremium::upgrade_notice');
                add_filter('upgrader_pre_download', 'oftsPremium::upgrader_pre_download', 10, 3);
                add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'ofts_add_plugin_action_links'));
                add_filter('plugin_row_meta', 'oftsPremium::plugin_row_meta', 10, 4);

            } else {

                add_filter('twentyseventeen_social_links_icons', array($this, 'ofts_social_links_icons'));
                add_action('wp_footer', array($this, 'ofts_include_svg_icons'), 9999);

            }

		}

		function ofts_add_plugin_action_links($links) {

			$settings_links = oftsCommon::plugin_action_links(admin_url('customize.php'), true);

			return array_merge($settings_links, $links);

		}

        function ofts_customize_register($wp_customize) {

            if (!class_exists('sidemenu_class')) {

                $wp_customize->add_section('sidemenu', array(
                    'title'     => __('SideMenu', 'options-for-twenty-seventeen'),
                    'description'  => __('Add a sliding SideMenu to Twenty Seventeen.', 'options-for-twenty-seventeen'),
                    'priority'     => 0
                ));

                oftsCommon::add_hidden_control($wp_customize, 'install_sidemenu', 'sidemenu', 'Install Sidemenu', sprintf(wp_kses(__('Add a slide-in side menu and widget area to the site by <a href="%s">installing SideMenu plugin</a>.', 'options-for-twenty-seventeen'), array('a' => array('href' => array()))), esc_url(wp_nonce_url(add_query_arg(array('action' => 'install-plugin', 'plugin' => 'sidemenu'), self_admin_url('update.php')), 'install-plugin_sidemenu'))));

            }

            $upgrade_link = '<a href="' . oftsCommon::upgrade_link() . '" title="' . __('Upgrade to Options for Twenty Seventeen Premium', 'options-for-twenty-seventeen') . '">' . __('Upgrade to Options for Twenty Seventeen Premium', 'options-for-twenty-seventeen') . '</a>';
            $upgrade_nag = $upgrade_link . __(' to activate this option.', 'options-for-twenty-seventeen');

            $control_label = __('Search / Archive Page Layout', 'options-for-twenty-seventeen');
            $control_description = __( 'When the two-column layout is assigned, the page title is in one column and content is in the other.', 'twentyseventeen' );

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('search_archive_page_layout', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('search_archive_page_layout', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'theme_options',
                'settings'      => 'search_archive_page_layout',
                'type'            => 'radio',
                'choices'         => array(
                    'one-column' => __( 'One Column', 'twentyseventeen' ),
                    '' => __( 'Two Column', 'twentyseventeen' ),
                ),
                'priority' => 5
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'search_archive_page_layout', 'theme_options', $control_label, $control_description . ' ' . $upgrade_nag, 5);

}

            $control_label = __('Front Page Sections', 'options-for-twenty-seventeen');
            $control_description = __('Set the number of sections on the static home page. You will need to save and re-load the Customiser to see changes.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('front_page_sections', array(
                'default'       => '4',
                'type'          => 'theme_mod',
                'transport'     => 'postMessage',
                'sanitize_callback' => 'absint'
            ));

            $wp_customize->add_control('front_page_sections', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'theme_options',
                'settings'      => 'front_page_sections',
                'type'          => 'select',
                'choices'       => range(1, 10),
                'priority' => 5,
			    'active_callback' => 'twentyseventeen_is_static_front_page'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'front_page_sections', 'theme_options', $control_label, $control_description . ' ' . $upgrade_nag, 5);

}

            $control_label = __('Panel Image Height', 'options-for-twenty-seventeen');
            $control_description = __('Set the height of the frontpage section parallax images.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('panel_image_height', array(
                'default'       => '101',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('panel_image_height', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'theme_options',
                'settings'      => 'panel_image_height',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 101,
                    'step'  => 1
                ),
                'priority' => 5,
			    'active_callback' => 'twentyseventeen_is_static_front_page'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'panel_image_height', 'theme_options', $control_label, $control_description . ' ' . $upgrade_nag, 5);

}

            $control_label = __('Blog Featured Images', 'options-for-twenty-seventeen');
            $control_description = __('Enable featured images in front page section blog page.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('front_page_section_blog_thumbnails', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('front_page_section_blog_thumbnails', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'theme_options',
                'settings'      => 'front_page_section_blog_thumbnails',
                'type'          => 'checkbox',
                'priority' => 5,
			    'active_callback' => 'twentyseventeen_is_static_front_page'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'front_page_section_blog_thumbnails', 'theme_options', $control_label, $control_description . ' ' . $upgrade_nag, 5);

}

            $control_label = __('Parallax Off', 'options-for-twenty-seventeen');
            $control_description = __('Turn on "true parallax" or turn off parallax effect altogether on front page section featured images and show full image in the usual flow of the page.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('front_page_sections_parallax', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('front_page_sections_parallax', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'theme_options',
                'settings'      => 'front_page_sections_parallax',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Parallax On', 'options-for-twenty-seventeen'),
                    'true' => __('True Parallax', 'options-for-twenty-seventeen'),
                    'off' => __('Parallax Off', 'options-for-twenty-seventeen'),
                ),
                'priority' => 5,
			    'active_callback' => 'twentyseventeen_is_static_front_page'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'front_page_sections_parallax', 'theme_options', $control_label, $control_description . ' ' . $upgrade_nag, 5);

}

            $control_label = __('Back to Top Link', 'options-for-twenty-seventeen');
            $control_description = __('Add a "Back to Top" link at the end of all pages.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('footer_back_to_top', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('footer_back_to_top', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'theme_options',
                'settings'      => 'footer_back_to_top',
                'type'          => 'checkbox',
                'priority' => 5
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'footer_back_to_top', 'theme_options', $control_label, $control_description . ' ' . $upgrade_nag, 5);

}

            $control_label = __('Fixed Back to Top Link', 'options-for-twenty-seventeen');
            $control_description = __('Fix the "Back to Top" link to the bottom right of the browser window.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('fix_footer_back_to_top', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('fix_footer_back_to_top', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'theme_options',
                'settings'      => 'fix_footer_back_to_top',
                'type'          => 'checkbox',
                'priority' => 5
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'fix_footer_back_to_top', 'theme_options', $control_label, $control_description . ' ' . $upgrade_nag, 5);

}

            $control_label = __('Front Page Section Back to Top Link', 'options-for-twenty-seventeen');
            $control_description = __('Add a "Back to Top" link to front page sections.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('front_page_sections_back_to_top', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('front_page_sections_back_to_top', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'theme_options',
                'settings'      => 'front_page_sections_back_to_top',
                'type'          => 'checkbox',
                'priority' => 5,
			    'active_callback' => 'twentyseventeen_is_static_front_page'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'front_page_sections_back_to_top', 'theme_options', $control_label, $control_description . ' ' . $upgrade_nag, 5);

}


            $control_label = __('Footer Background Opacity', 'options-for-twenty-seventeen');
            $control_description = __('Choose the opacity of the footer background color.', 'options-for-twenty-seventeen');

            if (oftsPremium::request_permission()) {

                $wp_customize->add_setting('footer_background_opacity', array(
                    'default'       => '11',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('footer_background_opacity', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'ofts_footer',
                    'settings'      => 'footer_background_opacity',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 1,
                        'max'   => 11,
                        'step'  => 1
                    )
                ));

            } else {

                oftsCommon::add_hidden_control($wp_customize, 'footer_background_opacity', 'ofts_footer', $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Page Background Image', 'options-for-twenty-seventeen');
            $control_description = __('Choose or upload an image to show in the website background.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('page_background_image', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'esc_attr'
            ));
            $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'page_background_image', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_general',
                'settings'      => 'page_background_image'
            )));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'page_background_image', 'ofts_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Page Background Image Style', 'options-for-twenty-seventeen');
            $control_description = __('Set the type of background image.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('page_background_image_style', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('page_background_image_style', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_general',
                'settings'      => 'page_background_image_style',
                'type'          => 'select',
                'choices'       => array(
                    '' => 'Default (Full Cover Image)',
                    'tiled' => __('Tiled / Repeating', 'options-for-twenty-seventeen')
                )
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'page_background_image_style', 'ofts_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Auto Excerpt Posts', 'options-for-twenty-seventeen');
            $control_description = __('Show first 55 words of a post with "Continue reading" link on home page and archive pages.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('auto_excerpt', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('auto_excerpt', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_general',
                'settings'      => 'auto_excerpt',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'auto_excerpt', 'ofts_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Set Number of Excerpt Words', 'options-for-twenty-seventeen');
            $control_description = __('Set the maximum number of words for the excerpt.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('auto_excerpt_words', array(
                'default'       => '55',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'absint'
            ));

            $wp_customize->add_control('auto_excerpt_words', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_general',
                'settings'      => 'auto_excerpt_words',
                'type'          => 'select',
                'choices'       => array_combine(range(25, 55, 5), range(25, 55, 5))
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'auto_excerpt_words', 'ofts_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Reset Tag Cloud Widget', 'options-for-twenty-seventeen');
            $control_description = __('Reverts Twenty Seventeen Tag Cloud Widget styling.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('reset_tag_cloud', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('reset_tag_cloud', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_general',
                'settings'      => 'reset_tag_cloud',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'reset_tag_cloud', 'ofts_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Header Height', 'options-for-twenty-seventeen');
            $control_description = __('Set the height of the header image on the home page.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('header_height', array(
                'default'       => '100',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('header_height', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'header_height',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 100,
                    'step'  => 1
                ),
			    'active_callback' => 'options_for_twenty_seventeen_class::ofts_has_header_image_or_nivo_slider'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'header_height', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Use Featured Image as Header Image', 'options-for-twenty-seventeen');
            $control_description = __('This option moves the featured image on single posts and pages to the header and makes the header image the same size as on the home page.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('featured_header_image', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('featured_header_image', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'featured_header_image',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'featured_header_image', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Hide Header Image', 'options-for-twenty-seventeen');
            $control_description = __('This option hides the header image on all pages except the home page.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('hide_header_image', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('hide_header_image', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'hide_header_image',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'hide_header_image', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Hide Site Branding', 'options-for-twenty-seventeen');
            $control_description = __('This option hides the site title and description on all pages except the home page.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('hide_site_branding', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('hide_site_branding', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'hide_site_branding',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'hide_site_branding', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Header Sidebar', 'options-for-twenty-seventeen');
            $control_description = __('Add a widget ready sidebar to the header area of the theme.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('header_sidebar', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('header_sidebar', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'header_sidebar',
                'type'          => 'select',
                'choices'       => array(
                    '' => 'No sidebar',
                    'top-left' => __('Position: Top, Left', 'options-for-twenty-seventeen'),
                    'top-center' => __('Position: Top, Center', 'options-for-twenty-seventeen'),
                    'top-right' => __('Position: Top, Right', 'options-for-twenty-seventeen')
                )
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'header_sidebar', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Hide YouTube Until Loaded', 'options-for-twenty-seventeen');
            $control_description = __('Hide the YouTube video in the header until it has started playing. The header image will be shown instead if there is one.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('hide_youtube_until_loaded', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('hide_youtube_until_loaded', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'hide_youtube_until_loaded',
                'type'          => 'checkbox',
                'active_callback' => 'options_for_twenty_seventeen_class::ofts_has_youtube_video'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'hide_youtube_until_loaded', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Pause YouTube on Scroll', 'options-for-twenty-seventeen');
            $control_description = __('Pause the YouTube video when the user scrolls down. Play again when the user scrolls back to the top of the page.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('pause_youtube_on_scroll', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('pause_youtube_on_scroll', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'pause_youtube_on_scroll',
                'type'          => 'checkbox',
                'active_callback' => 'options_for_twenty_seventeen_class::ofts_has_youtube_video'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'pause_youtube_on_scroll', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Video Looping Off', 'options-for-twenty-seventeen');
            $control_description = __('Prevent the header video from looping. This currently is developed for .mp4 videos, contact us if you need this feature for a YouTube video.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('video_looping_off', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('video_looping_off', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'video_looping_off',
                'type'          => 'checkbox',
                'active_callback' => 'has_header_video'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'video_looping_off', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('True Parallax Cover Image', 'options-for-twenty-seventeen');
            $control_description = __('Turn on "true parallax" scrolling for the header cover image.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('true_parallax_cover_image', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('true_parallax_cover_image', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'true_parallax_cover_image',
                'type'          => 'checkbox',
                'active_callback' => 'options_for_twenty_seventeen_class::ofts_has_header_image_or_nivo_slider'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'true_parallax_cover_image', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('True Parallax Speed', 'options-for-twenty-seventeen');
            $control_description = __('Set the parallax scroll speed.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('true_parallax_speed', array(
                'default'           => 50,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('true_parallax_speed', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'true_parallax_speed',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 100,
                    'step'  => 1
                ),
                'active_callback' => 'options_for_twenty_seventeen_class::ofts_has_header_image_or_nivo_slider'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'true_parallax_speed', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Slider Cover', 'options-for-twenty-seventeen');
            $control_description = sprintf(
                wp_kses(__('Replaces the cover image with a <a href="%s">Sliderspack</a> or <a href="%s">MetaSlider</a> Slider. Remember to set "Image Size" to "Twenty-Seventeen-featured-image" in your slider settings for best results.', 'options-for-twenty-seventeen'), array('a' => array('href' => array()))),
                esc_url(add_query_arg(array(
                    's' => 'sliderspack-all-in-one-image-sliders',
                    'tab' => 'search',
                    'type' => 'term'
                ), admin_url('plugin-install.php'))), esc_url(add_query_arg( array(
                    's' => 'ml-slider',
                    'tab' => 'search',
                    'type' => 'term'
                ), admin_url('plugin-install.php')))
            );

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('nivo_slider_cover', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $installed_sliders = array();

            if (function_exists('nivo_slider')) {

                $installed_sliders[] = 'nivoslider';

            }

            if (function_exists('wp_spaios_slider_shortcode')) {

                $installed_sliders[] = 'wpspaios_slider';

            }

            if (class_exists('MetaSliderPlugin')) {

                $installed_sliders[] = 'ml-slider';

            }

            if (class_exists('smoothslides_class')) {

                $installed_sliders[] = 'smoothslides';

            }

            $nivo_sliders_array = array('' => 'No slider');

            if (!empty($installed_sliders)) {

                $nivo_sliders = get_posts(array(
                    'post_type' => $installed_sliders,
                    'posts_per_page' => -1,
                ));

                foreach ($nivo_sliders as $nivo_slider) {

                    $nivo_sliders_array[$nivo_slider->ID] = $nivo_slider->post_title;

                }

            }

            $wp_customize->add_control('nivo_slider_cover', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'nivo_slider_cover',
                'type'          => 'select',
                'choices'       => $nivo_sliders_array
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'nivo_slider_cover', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Enable Nivo Captions', 'options-for-twenty-seventeen');
            $control_description = __('Overlay slide captions on Nivo Slider.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('enable_nivo_captions', array(
                'default'       => false,
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('enable_nivo_captions', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_header',
                'settings'      => 'enable_nivo_captions',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'enable_nivo_captions', 'ofts_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Add Logo to Navigation Bar', 'options-for-twenty-seventeen');
            $control_description = __('Move or copy the Site Logo to the Navigation Bar.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('add_logo_to_nav', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('add_logo_to_nav', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'add_logo_to_nav',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Select option ...', 'options-for-twenty-seventeen'),
                    'copy' => __('Copy Logo', 'options-for-twenty-seventeen'),
                    'move' => __('Move Logo', 'options-for-twenty-seventeen')
                )
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'add_logo_to_nav', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Show Nav Logo on Mobile', 'options-for-twenty-seventeen');
            $control_description = __('If the logo has been added to the Navigation Bar, show it on small screens as well.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('show_mobile_nav_logo', array(
                'default'       => false,
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('show_mobile_nav_logo', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'show_mobile_nav_logo',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'show_mobile_nav_logo', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Animate Logo in Navigation Bar', 'options-for-twenty-seventeen');
            $control_description = __('Shrinks the logo in the Navigation Bar when the user scrolls.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('animate_nav_logo', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('animate_nav_logo', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'animate_nav_logo',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Select option ...', 'options-for-twenty-seventeen'),
                    'home' => __('Animate on home page only', 'options-for-twenty-seventeen'),
                    'all' => __('Animate on all pages', 'options-for-twenty-seventeen')
                )
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'animate_nav_logo', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Move Navigation Bar to Top', 'options-for-twenty-seventeen');
            $control_description = __('Moves the main menu to the top of the custom header.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('move_nav_bar_to_top', array(
                'default'       => false,
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('move_nav_bar_to_top', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'move_nav_bar_to_top',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'move_nav_bar_to_top', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Fix Mobile Navigation Bar to Top', 'options-for-twenty-seventeen');
            $control_description = __('Fixes the mobile navigation bar to the top of the screen.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('fix_mobile_nav_bar_to_top', array(
                'default'       => false,
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('fix_mobile_nav_bar_to_top', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'fix_mobile_nav_bar_to_top',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'fix_mobile_nav_bar_to_top', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Navigation Responsive Breakpoint', 'options-for-twenty-seventeen');
            $control_description = __('Increase or decrease the point at which the main menu becomes a mobile menu.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('nav_responsive_breakpoint', array(
                'default'           => 0,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('nav_responsive_breakpoint', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'nav_responsive_breakpoint',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 0,
                    'max'   => 32,
                    'step'  => 1
                ),
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'nav_responsive_breakpoint', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Decrease Nav Breakpoint', 'options-for-twenty-seventeen');
            $control_description = __('Use the above control to decrease the breakpoint instead of increasing it.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('nav_decrease_breakpoint', array(
                'default'       => false,
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('nav_decrease_breakpoint', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'nav_decrease_breakpoint',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'nav_decrease_breakpoint', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Navigation Hamburger Alignment', 'options-for-twenty-seventeen');
            $control_description = __('Align the navigation menu hamburger on smaller screens to the left, center or right.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('nav_hamburger_align', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'postMessage',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('nav_hamburger_align', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'nav_hamburger_align',
                'type'          => 'select',
                'choices'       => array(
                    'left' => __('Left', 'options-for-twenty-seventeen'),
                    '' => __('Center', 'options-for-twenty-seventeen'),
                    'right' => __('Right', 'options-for-twenty-seventeen')
                )
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'nav_hamburger_align', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Navigation Alignment', 'options-for-twenty-seventeen');
            $control_description = __('Align the navigation menu items to the left, center or right.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('nav_text_align', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('nav_text_align', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'nav_text_align',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Left', 'options-for-twenty-seventeen'),
                    'center' => __('Center', 'options-for-twenty-seventeen'),
                    'right' => __('Right', 'options-for-twenty-seventeen'),
                    'justify' => __('Justify', 'options-for-twenty-seventeen')
                )
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'nav_text_align', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Navigation Logo Alignment', 'options-for-twenty-seventeen');
            $control_description = __('Align the logo in the main menu, if present.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('nav_logo_align', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('nav_logo_align', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'nav_logo_align',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Automatic', 'options-for-twenty-seventeen'),
                    'left' => __('Left', 'options-for-twenty-seventeen'),
                    'center' => __('Center', 'options-for-twenty-seventeen'),
                    'right' => __('Right', 'options-for-twenty-seventeen')
                )
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'nav_logo_align', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Bounce Navigation Scroll Down Arrow', 'options-for-twenty-seventeen');
            $control_description = __('Animates the arrow at the end of the main menu.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('bounce_nav_scroll_arrow', array(
                'default'       => false,
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('bounce_nav_scroll_arrow', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'bounce_nav_scroll_arrow',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'bounce_nav_scroll_arrow', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Move Scroll Down Arrow', 'options-for-twenty-seventeen');
            $control_description = __('Moves the arrow at the end of the main menu above the navigation.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('move_nav_scroll_arrow', array(
                'default'       => false,
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('move_nav_scroll_arrow', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_navigation',
                'settings'      => 'move_nav_scroll_arrow',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'move_nav_scroll_arrow', 'ofts_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Hide Blog Sidebar for Mobile', 'options-for-twenty-seventeen');
            $control_description = __('Hides the Blog Sidebar widget area on small screens.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('hide_blog_sidebar', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('hide_blog_sidebar', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'hide_blog_sidebar',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'hide_blog_sidebar', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Match Content and Sidebar Height', 'options-for-twenty-seventeen');
            $control_description = __('Matches the height of the Blog Sidebar to the Primary Content.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('match_primary_secondary_height', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('match_primary_secondary_height', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'match_primary_secondary_height',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'match_primary_secondary_height', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Primary Content Area Width', 'options-for-twenty-seventeen');
            $control_description = __('Change the width of the Primary Content area.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('primary_width', array(
                'default'           => 58,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('primary_width', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'primary_width',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 58,
                    'max'   => 70,
                    'step'  => 1
                ),
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'primary_width', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Content Margin / Gutter', 'options-for-twenty-seventeen');
            $control_description = __('Change the gap between the Primary Content area and the Blog Sidebar.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('content_gutter', array(
                'default'           => 7,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('content_gutter', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'content_gutter',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 7,
                    'step'  => 1
                ),
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'content_gutter', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Swap Content and Sidebar', 'options-for-twenty-seventeen');
            $control_description = __('Moves the Blog Sidebar to the left of the Primary Content.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('swap_content', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('swap_content', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'swap_content',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'swap_content', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Implement Yoast SEO Breadcrumbs', 'options-for-twenty-seventeen');
            $control_description = sprintf(wp_kses(__('Inject <a href="%s">Yoast SEO</a> breadcrumbs above and / or below single post and page content.', 'options-for-twenty-seventeen'), array('a' => array('href' => array()))), esc_url(admin_url('plugin-install.php?s=wordpress-seo&tab=search&type=term')));

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('implement_yoast_breadcrumbs', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('implement_yoast_breadcrumbs', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'implement_yoast_breadcrumbs',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Disable Breadcrumbs', 'options-for-twenty-seventeen'),
                    'top' => __('Above Content', 'options-for-twenty-seventeen'),
                    'bottom' => __('Below Content', 'options-for-twenty-seventeen'),
                    'both' => __('Above and Below Content', 'options-for-twenty-seventeen')
                )
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'implement_yoast_breadcrumbs', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Inject Featured Image Caption', 'options-for-twenty-seventeen');
            $control_description = __('Overlays the image caption onto the featured image.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('inject_featured_image_caption', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('inject_featured_image_caption', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'inject_featured_image_caption',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'inject_featured_image_caption', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Featured Image Caption Font Size', 'options-for-twenty-seventeen');
            $control_description = __('Change the font size of featured image captions.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('featured_image_caption_font_size', array(
                'default'           => 2250,
                'type'              => 'theme_mod',
                'transport'         => 'postMessage',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('featured_image_caption_font_size', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'featured_image_caption_font_size',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 875,
                    'max'   => 3625,
                    'step'  => 125
                ),
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'featured_image_caption_font_size', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Featured Image Caption Font Weight', 'options-for-twenty-seventeen');
            $control_description = __('Change the font weight of featured image captions.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('featured_image_caption_font_weight', array(
                'default'           => 800,
                'type'              => 'theme_mod',
                'transport'         => 'postMessage',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('featured_image_caption_font_weight', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'featured_image_caption_font_weight',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 100,
                    'max'   => 900,
                    'step'  => 100
                ),
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'featured_image_caption_font_weight', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Move Featured Image', 'options-for-twenty-seventeen');
            $control_description = __('Move the featured image into the post content.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('move_featured_image', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('move_featured_image', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'move_featured_image',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'move_featured_image', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Hide Archive Featured Images', 'options-for-twenty-seventeen');
            $control_description = __('Hide post featured images on Archive pages.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('hide_archive_featured_images', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'postMessage',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('hide_archive_featured_images', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'hide_archive_featured_images',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'hide_archive_featured_images', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Hide Post Dates', 'options-for-twenty-seventeen');
            $control_description = __('Prevents Wordpress from displaying the date of a post.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('remove_posted_on', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'postMessage',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('remove_posted_on', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'remove_posted_on',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'remove_posted_on', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Hide Post Author', 'options-for-twenty-seventeen');
            $control_description = __('Prevents Wordpress from displaying the author of a post.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('remove_author', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('remove_author', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'remove_author',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'remove_author', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Remove Category and Tag from Archive Titles', 'options-for-twenty-seventeen');
            $control_description = __('Remove the words "Category: " and "Tag: " from archive page titles.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('remove_category_tag', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('remove_category_tag', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'remove_category_tag',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'remove_category_tag', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}


            $control_label = __('Show Page Content on Posts Page', 'options-for-twenty-seventeen');
            $control_description = __('Show the content of the chosen posts page above the posts. NB: You will need to unassign it as the posts page in order to edit the content.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('show_content_on_posts_page', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('show_content_on_posts_page', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_content',
                'settings'      => 'show_content_on_posts_page',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'show_content_on_posts_page', 'ofts_content', $control_label, $control_description . ' ' . $upgrade_nag);

}


            $control_label = __('Footer Background Image', 'options-for-twenty-seventeen');
            $control_description = __('Choose or upload an image to show in the background of the footer area.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('footer_background_image', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'postMessage',
                'sanitize_callback' => 'esc_attr'
            ));
            $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'footer_background_image', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_footer',
                'settings'      => 'footer_background_image'
            )));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'footer_background_image', 'ofts_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Footer Sidebars', 'options-for-twenty-seventeen');
            $control_description = __('Add a third or fourth widget ready sidebar to the footer area of the theme.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('footer_sidebars', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('footer_sidebars', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_footer',
                'settings'      => 'footer_sidebars',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('2 Footer Sidebars', 'options-for-twenty-seventeen'),
                    '3' => __('3 Footer Sidebars', 'options-for-twenty-seventeen'),
                    '4' => __('4 Footer Sidebars', 'options-for-twenty-seventeen')
                )
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'footer_sidebars', 'ofts_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Fix Social Links', 'options-for-twenty-seventeen');
            $control_description = __('Fix the social links to the left or right for large screens.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('fix_social_links', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_options'
            ));
            $wp_customize->add_control('fix_social_links', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_footer',
                'settings'      => 'fix_social_links',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Do not fix', 'options-for-twenty-seventeen'),
                    'left' => __('Fix to the left', 'options-for-twenty-seventeen'),
                    'right' => __('Fix to the right', 'options-for-twenty-seventeen')
                )
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'fix_social_links', 'ofts_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Square Social Links', 'options-for-twenty-seventeen');
            $control_description = __('Make the social links menu items square.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('square_social_links', array(
                'default'       => false,
                'type'          => 'theme_mod',
                'transport'     => 'postMessage',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('square_social_links', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_footer',
                'settings'      => 'square_social_links',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'square_social_links', 'ofts_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Add Colors to Social Links Menu', 'options-for-twenty-seventeen');
            $control_description = __('Changes the background of the social links menu items to their relevant corporate colors.', 'options-for-twenty-seventeen');

if (oftsPremium::request_permission()) {

            $wp_customize->add_setting('colored_social_links_menu', array(
                'default'       => false,
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'oftsCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('colored_social_links_menu', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'ofts_footer',
                'settings'      => 'colored_social_links_menu',
                'type'          => 'checkbox'
            ));

} else {

            oftsCommon::add_hidden_control($wp_customize, 'colored_social_links_menu', 'ofts_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

        }

        function ofts_header_output() {

            global $post;

?>
<!--Customizer CSS-->
<style type="text/css">
<?php

if (oftsPremium::request_permission(true) == true) {

            if ((is_page() || is_single()) && get_post_meta(get_the_ID(), 'ofts_hide_title', true) == '1') {

                if (is_page()) {

?>
#main article:first-of-type .entry-header {
    display: none;
}
<?php

                } else {

?>
#main article:first-of-type .entry-title {
    display: none;
}
<?php

                }

            }

}

if (oftsPremium::request_permission(true) == true) {

            if (get_theme_mod('external_header_video')) {

                if (get_theme_mod('hide_youtube_until_loaded')) {

                    add_action('wp_footer', array($this, 'ofts_hide_youtube_until_loaded'));

                }

                if (get_theme_mod('pause_youtube_on_scroll')) {

                    add_action('wp_footer', array($this, 'ofts_pause_youtube_on_scroll'));

                }

            }

            if (has_header_video()) {

                if (get_theme_mod('video_looping_off')) {

                    add_action('wp_footer', array($this, 'ofts_video_looping_off'));

                }

            }

            if (get_theme_mod('search_archive_page_layout') == 'one-column') {
?>
@media screen and (min-width: 48em) {
    body:not(.has-sidebar):not(.page-one-column) .page-header, body.has-sidebar.error404 #primary .page-header, body.page-two-column:not(.archive) #primary .entry-header, body.page-two-column.archive:not(.has-sidebar) #primary .page-header {
        float: none;
        width: 100%;
    }
    .blog:not(.has-sidebar) #primary article, .archive:not(.page-one-column):not(.has-sidebar) #primary article, .search:not(.has-sidebar) #primary article, .error404:not(.has-sidebar) #primary .page-content, .error404.has-sidebar #primary .page-content, body.page-two-column:not(.archive) #primary .entry-content, body.page-two-column #comments {
        float: none;
        width: 100%;
    }
}
<?php
            }

            $mod = get_theme_mod('panel_image_height');

            if ($mod) {
?>
@media screen and (min-width: 48em) {
    .panel-image {
        height: <?= absint($mod) - 1; ?>vh;
    }
}
<?php
            }

            if (get_theme_mod('front_page_section_blog_thumbnails')) {

                add_action('get_template_part_template-parts/post/content', array($this, 'ofts_inject_excerpt_post_thumbnails'), 10, 2);

            }

            $mod = get_theme_mod('front_page_sections_parallax');

            if ($mod == 'off') {
?>
@media screen and (min-width: 48em) {
    .background-fixed .panel-image {
        background-attachment: scroll;
    }
    .panel-image {
        height: auto;
    }
}
.panel-image:before {
    background: none;
}
<?php
            } elseif ($mod == 'true') {

                add_action('get_footer', array($this, 'ofts_inject_true_parallax'));

            }

            if (get_theme_mod('footer_back_to_top')) {

                add_action('get_footer', array($this, 'ofts_inject_footer_back_to_top'));

                if (get_theme_mod('fix_footer_back_to_top')) {
?>
.back-to-top-footer a {
	position: fixed;
	background: #767676;
	bottom: 2em;
	right: 2em;
	padding: 0.5em 0.75em;
	margin-bottom: 0;
	border-radius: 50%;
}

.back-to-top-footer svg {
	color: white;
}

.back-to-top-footer a:hover {
	background: #333;
}
.back-to-top-footer .screen-reader-text {
	width: 0;
}
<?php
                }

            }

            if (get_theme_mod('front_page_sections_back_to_top')) {

                add_action('get_template_part_template-parts/page/content', array($this, 'ofts_inject_front_page_sections_to_back_to_top'), 10, 2);

            }

            if (get_theme_mod('true_parallax_cover_image')) {

                add_action('get_footer', array($this, 'ofts_inject_header_true_parallax'));
?>
.has-header-image .custom-header-media img, .has-header-image .custom-header-media iframe {
	object-position: 50% 0;
}
.admin-bar.has-header-image .custom-header-media img {
	object-position: 50% 16px;
}
<?php
            }

            $mod = get_theme_mod('page_background_image');

            if ($mod) {

?>
body, body.colors-dark, body.colors-custom {
background-image: url("<?= $mod; ?>");
background-attachment: fixed;
}
<?php

            }

            if (get_theme_mod('page_background_image_style')) {

?>
body, body.colors-dark, body.colors-custom {
background-repeat: repeat;
}
<?php

            } else {

?>
body, body.colors-dark, body.colors-custom {
background-size: cover;
background-position: center center;
background-repeat: no-repeat;
}
<?php

            }

            if (get_theme_mod('auto_excerpt')) {

                add_filter('the_content', array($this, 'ofts_auto_excerpt'));

            }

            if (get_theme_mod('reset_tag_cloud')) {

                add_filter('widget_tag_cloud_args', array($this, 'ofts_reset_tag_cloud_args'), 11);
?>
.tagcloud,
.widget_tag_cloud,
.wp_widget_tag_cloud {
	line-height: 1.6;
}

.widget .tagcloud a,
.widget.widget_tag_cloud a,
.wp_widget_tag_cloud a {
	border: none;<?php if (!get_theme_mod('remove_link_underlines')) { ?>
	-webkit-box-shadow: inset 0 -1px 0 rgba(15, 15, 15, 1);
	box-shadow: inset 0 -1px 0 rgba(15, 15, 15, 1);<?php } ?>
	-webkit-transition: color 80ms ease-in, -webkit-box-shadow 130ms ease-in-out;
	transition: color 80ms ease-in, -webkit-box-shadow 130ms ease-in-out;
	transition: color 80ms ease-in, box-shadow 130ms ease-in-out;
	transition: color 80ms ease-in, box-shadow 130ms ease-in-out, -webkit-box-shadow 130ms ease-in-out;
	display: inline;
	padding: 0;
	position: static;
	z-index: auto;
}

.widget .tagcloud a:hover,
.widget .tagcloud a:focus,
.widget.widget_tag_cloud a:hover,
.widget.widget_tag_cloud a:focus,
.wp_widget_tag_cloud a:hover,
.wp_widget_tag_cloud a:focus {
	border: none;<?php if (!get_theme_mod('remove_link_underlines')) { ?>
	-webkit-box-shadow: inset 0 0 0 rgba(0, 0, 0, 0), 0 3px 0 rgba(0, 0, 0, 1);
	box-shadow: inset 0 0 0 rgba(0, 0, 0, 0), 0 3px 0 rgba(0, 0, 0, 1);<?php } ?>
}
<?php

            }

?>
@media screen and (min-width: 48em) {
<?php

            oftsCommon::generate_css('.twentyseventeen-front-page.has-header-image .custom-header-media, .twentyseventeen-front-page.has-header-video .custom-header-media, .home.blog.has-header-image .custom-header-media, .home.blog.has-header-video .custom-header-media', 'height', 'header_height', '', 'vh');
            oftsCommon::generate_css('.admin-bar.twentyseventeen-front-page.has-header-image .custom-header-media, .admin-bar.twentyseventeen-front-page.has-header-video .custom-header-media, .admin-bar.home.blog.has-header-image .custom-header-media, .admin-bar.home.blog.has-header-video .custom-header-media', 'height', 'header_height', '', '', 'calc(' . get_theme_mod('header_height') . 'vh - 32px)');

?>
}
<?php

            if (get_theme_mod('featured_header_image') && !is_front_page()) {

                add_action('get_template_part_template-parts/page/content', array($this, 'ofts_featured_header_image'));
                add_action('get_template_part_template-parts/post/content', array($this, 'ofts_featured_header_image'));

                if (has_custom_header()) {
?>
@media screen and (min-width: 48em) {
    .has-header-image .custom-header {
        display: block;
        height: auto;
        margin-bottom: 0 !important;
    }
    .has-header-image:not(.twentyseventeen-front-page):not(.home) .custom-header-media {
        height: 1200px;
        height: 100vh;
        max-height: 100%;
        overflow: hidden;
        bottom: auto;
        left: auto;
        position: relative;
        right: auto;
        top: auto;
    }
    .admin-bar.has-header-image:not(.twentyseventeen-front-page):not(.home) .custom-header-media {
        height: calc(100vh - 32px);
    }
    .has-header-image:not(.twentyseventeen-front-page):not(.home) .custom-header-media img {
        position: fixed;
        bottom: auto;
    }
    .has-header-image .site-branding {
        bottom: 0;
        display: block;
        left: 0;
        height: auto;
        padding-top: 0;
        position: absolute;
        width: 100%;
        margin-bottom: 83px;
    }
    body.title-tagline-hidden.has-header-image .custom-logo-link img {
        max-height: 200px;
    }
<?php

                    oftsCommon::generate_css('.has-header-image:not(.twentyseventeen-front-page):not(.home) .custom-header-media', 'height', 'header_height', '', 'vh');
                    oftsCommon::generate_css('.admin-bar.has-header-image:not(.twentyseventeen-front-page):not(.home) .custom-header-media', 'height', 'header_height', 'calc(', 'vh - 32px)');

?>
}
<?php

                }

            }

            if (get_theme_mod('hide_header_image') && !is_front_page() && has_custom_header()) {

?>
.site-branding {
    display: none;
}
<?php

            }

            if (get_theme_mod('hide_site_branding') && !is_front_page() && has_custom_header()) {

?>
.site-branding {
    visibility: hidden;
}
<?php

            }

            if (get_theme_mod('header_sidebar')) {

                add_action('get_template_part_template-parts/header/header', array($this, 'ofts_get_header_sidebar'));

                if (has_custom_header()) {
?>
#header-sidebar {
    padding: 0 3em;
    position: absolute;
    z-index: 6;
    color: white;
}
#header-sidebar.top-left {
    top: 0;
    left: 0;
}
#header-sidebar.top-center {
    top: 0;
    left: 0;
    right: 0;
    text-align: center;
}
#header-sidebar.top-right {
    top: 0;
    right: 0;
}
#header-sidebar h2 {
    color: white;
}
<?php
                }

            }

            if (get_theme_mod('nivo_slider_cover') && is_front_page()) {

                add_action('get_template_part_template-parts/header/site', array($this, 'ofts_nivo_slider'));
                add_filter('body_class', array($this, 'ofts_header_image_body_class'));

                $slider_post_type = get_post_type(get_theme_mod('nivo_slider_cover'));

                if ($slider_post_type == 'nivoslider') {

?>
.custom-header-media:nth-of-type(1) {
    display: none;
}
.has-header-image .custom-header-media img, .has-header-video .custom-header-media video, .has-header-video .custom-header-media iframe {
    position: absolute;
    padding: 0;
}
.has-header-image .custom-header, .has-header-video .custom-header, .has-header-video .custom-header {
    position: relative;
}
.site-branding, .navigation-top, .custom-header-media:before {
    z-index: 6;
}
.has-header-image.twentyseventeen-front-page .custom-header, .has-header-video.twentyseventeen-front-page .custom-header, .has-header-image.home.blog .custom-header, .has-header-video.home.blog .custom-header {
	height: calc(100vw / 2000 * 1200 );
	max-height: 100vh;
}
/* IE11 fix */
.has-header-image .custom-header-media img, .has-header-image:not(.twentyseventeen-front-page):not(.home) .custom-header-media img {
    left: 0;
    transform: none;
}
<?php

                    if (get_theme_mod('enable_nivo_captions')) {

?>
header .nivo-caption {
    padding: 0;
    bottom: auto;
    background: none;
    top: 0.5rem;
    left: 2rem;
    right: 2rem;
    opacity: 1;
	position: absolute;
 	font-size: 1.5rem;
	text-transform: uppercase;
	font-weight: 800;
}
header .nivo-caption a {
	color: white;
	display: block !important;
}
@media screen and (min-width: 48em) {
	header .nivo-caption {
		font-size: 2.25rem;
        left: 3rem;
        right: 3rem;
	}
}
<?php

                    }

                } elseif ($slider_post_type == 'wpspaios_slider') {

?>
.custom-header-media:nth-of-type(1) {
    display: none;
}
.nivoSlider.wp-spaios-nivoslider-container {
    max-width: none !important;
}
.site-branding, .navigation-top {
    z-index: 10;
}
.has-header-image .custom-header-media img, .has-header-video .custom-header-media video, .has-header-video .custom-header-media iframe {
    position: static;
}
.has-header-image .custom-header-media img, .has-header-video .custom-header-media video, .has-header-image:not(.twentyseventeen-front-page):not(.home) .custom-header-media img {
    height: 100vh !important;
}
<?php

                } elseif ($slider_post_type == 'ml-slider') {

?>
.custom-header-media:nth-of-type(1) {
    display: none;
}
.site-branding, .navigation-top {
    z-index: 10;
}
.has-header-image .custom-header-media img, .has-header-video .custom-header-media video, .has-header-video .custom-header-media iframe {
    position: static;
}
.has-header-image .custom-header-media img, .has-header-video .custom-header-media video, .has-header-image:not(.twentyseventeen-front-page):not(.home) .custom-header-media img {
    height: 100vh !important;
}
<?php

                } elseif ($slider_post_type == 'smoothslides') {

?>
.custom-header-media:nth-of-type(1) {
    display: none;
}
.has-header-image .custom-header-media img {
    position: relative;
}
.smoothslides, .smoothslides-on, .ss-slide-stage {
    border-radius: 0;
}
.custom-header-media {
	position: relative;
}
.twentyseventeen-front-page.has-header-image .custom-header-media {
	height: auto;
	max-height: 100vh;
}
.admin-bar.twentyseventeen-front-page.has-header-image .custom-header-media {
	max-height: calc(100vh - 32px);
}
.has-header-image.twentyseventeen-front-page .custom-header {
	height: auto;
}
.ss-caption-wrap {
	bottom: auto;
	top: 40%;
}
.ss-caption {
	left: 0;
	position: absolute;
	width: 100%;
	font-family: 'Verdana',sans-serif;
	text-transform: uppercase;
	background: none;
	color: white;
}
<?php

                }

            }

            $mod = get_theme_mod('add_logo_to_nav');

            if ($mod) {

                add_action('get_template_part_template-parts/navigation/navigation', array($this, 'ofts_add_logo_to_nav'));

                $position = get_theme_mod('nav_logo_align');

                if (!$position) {

                    if (get_theme_mod('nav_text_align')) {

                        $position = 'left';

                    } else {

                        $position = 'right';

                    }

                }

?>
#site-navigation {
    position: relative;
}
body.title-tagline-hidden.has-header-image .custom-logo-link img,
.navigation-top .custom-logo-link img, body.home.title-tagline-hidden.has-header-image .navigation-top .custom-logo-link img, body.home.title-tagline-hidden.has-header-video .navigation-top .custom-logo-link img {
	<?php if (((get_theme_mod('animate_nav_logo') == 'home' && is_front_page()) || get_theme_mod('animate_nav_logo') == 'all') && $position != 'center') { ?>position: absolute<?php } elseif (!((get_theme_mod('animate_nav_logo') == 'home' && is_front_page()) || get_theme_mod('animate_nav_logo') == 'all') && $position != 'center') { ?>float: <?php if ($position == 'left') { ?>left<?php } else { ?>right<?php } } ?>;
	<?php if ($position == 'right' && ((get_theme_mod('animate_nav_logo') == 'home' && is_front_page()) || get_theme_mod('animate_nav_logo') == 'all')) { ?>right: 0;
<?php } ?>	max-height: <?php if ((get_theme_mod('animate_nav_logo') == 'home' && is_front_page()) || get_theme_mod('animate_nav_logo') == 'all') { ?>none<?php } else { ?>49px<?php } ?>;
}
<?php if ($position != 'center') { ?>.navigation-top .custom-logo-link {
	padding: 0;
}<?php

                }

                if (!get_theme_mod('show_mobile_nav_logo')) {

?>
@media screen and (max-width: 48em) {
	.navigation-top .custom-logo-link {
		display: none;
	}
}
<?php

                }

                if ($mod == 'move') {

?>
.site-branding .custom-logo-link {
	display: none;
}
<?php

                }

            }

            if (get_theme_mod('move_nav_bar_to_top')) {

                add_action('wp_footer', array($this, 'ofts_check_nav_height'));

?>
@media screen and (min-width: 48em) {
	.navigation-top {
		position: fixed;
		bottom: auto;
		top: 0;
	}
	.admin-bar .navigation-top {
		top: 32px;
	}
	.custom-header {
		margin-top: 72px;
		margin-bottom: 0 !important;
	}
	.has-header-image .custom-header-media img {
		padding-bottom: 0;
	}
}
<?php

            }

            if (get_theme_mod('fix_mobile_nav_bar_to_top')) {

?>
@media screen and (max-width: 767px) {
    .navigation-top {
        position: fixed;
        top: 0;
        left: 0;
        right: 0;
        z-index: 7;
    }
}
@media screen and (max-width: 48em) {
    #page {
        margin-top: 49px;
    }
}
<?php

            }

            if (get_theme_mod('nav_responsive_breakpoint')) {

                if (get_theme_mod('nav_decrease_breakpoint')) {

?>
@media screen and (min-width: <?= 48 - absint(get_theme_mod('nav_responsive_breakpoint')); ?>em) {
	.js .menu-toggle,
	.js .dropdown-toggle {
		display: none;
	}
	.js .main-navigation > div > ul {
		display: block;
	}
    .navigation-top {
        position: relative;
    }
    .main-navigation li {
        display: inline-block;
    }
}
<?php

                } else {

?>
@media screen and (min-width: 48em) {
	.js .menu-toggle {
		display: block;
	}
	.js .main-navigation > div > ul {
		display: none;
	}
    .navigation-top {
        position: <?php get_theme_mod('move_nav_bar_to_top') ? 'fixed' : 'static'; ?>;
    }
}
@media screen and (min-width: <?= get_theme_mod('nav_responsive_breakpoint') + 48; ?>em) {
	.js .menu-toggle,
	.js .dropdown-toggle {
		display: none;
	}
	.js .main-navigation > div > ul {
		display: block;
	}
    .navigation-top {
        position: <?php get_theme_mod('move_nav_bar_to_top') ? 'fixed' : 'absolute'; ?>;
    }
}
<?php

                }

            }

            $mod = get_theme_mod('nav_hamburger_align');

            if ($mod == 'left') {
?>
.menu-toggle {
    margin: 0 auto 0 0;
}
<?php
            } elseif ($mod == 'right') {
?>
.menu-toggle {
    margin: 0 0 0 auto;
}
<?php

            }

            $mod = get_theme_mod('nav_text_align');

            if ($mod == 'justify') {

?>
@media screen and (min-width: 48em) {
    .js .main-navigation ul, .js .main-navigation ul ul, .js .main-navigation > div > ul {
        display: flex;
        justify-content: space-between;
    }
}
<?php

            } elseif ($mod) {

?>
@media screen and (min-width: 48em) {
    .main-navigation>div>ul {
        text-align: <?= $mod; ?>;
    }
}
<?php

                if ($mod == 'right') {
?>
.main-navigation ul ul li:hover > ul,
.main-navigation ul ul li.focus > ul {
	right: 100%;
	left: auto;
}
@media screen and (min-width: 48em) {
    .main-navigation ul ul .menu-item-has-children > a > .icon, .main-navigation ul ul .page_item_has_children > a > .icon {
        transform: rotate(90deg);
    }
}
<?php

                }

            }

            if (get_theme_mod('bounce_nav_scroll_arrow')) {

?>
.menu-scroll-down {
  animation: bounce 2s infinite;
}
@keyframes bounce {
  0%, 20%, 50%, 80%, 100% {
    transform: translateY(0);
  }
  40% {
    transform: translateY(-30px);
  }
  60% {
    transform: translateY(-15px);
  }
}
<?php
            }

            if (get_theme_mod('move_nav_scroll_arrow')) {

?>
@media screen and (min-width: 48em) {
	.site-header .navigation-top .menu-scroll-down {
	    color: white;
        top: -90px
	}
}
<?php

            }

            if (get_theme_mod('hide_blog_sidebar')) {

?>
@media screen and (max-width: 48em) {
	#secondary {
		display: none;
	}
}
<?php
            }

            if (get_theme_mod('match_primary_secondary_height')) {

                add_action('get_sidebar', array($this, 'ofts_match_primary_secondary_height'));

            }

            $primary_width = get_theme_mod('primary_width');
            $content_gutter = get_theme_mod('content_gutter');

            if ($primary_width || $content_gutter) {

                if (!$primary_width) { $primary_width = 58; }
                if (!$content_gutter) { $content_gutter = 6; }

?>
@media screen and (min-width: 48em) {
    .has-sidebar:not(.error404) #primary {
        width: <?= $primary_width; ?>%;
    }
    .has-sidebar #secondary {
        width: <?= 100 - $primary_width - $content_gutter + 1; ?>%;
    }
}
<?php

            }

            if (get_theme_mod('swap_content')) {

?>
@media screen and (min-width: 48em) {
    .has-sidebar:not(.error404) #primary {
        float: right;
    }
    .has-sidebar #secondary {
        float: left;
    }
}
<?php

            }

            if (is_single() && isset($post->ID) && get_post_meta($post->ID, 'ofts_hide_page_sidebar', true) == '1') {
?>
#secondary {
    display: none;
}
@media screen and (min-width: 48em) {
    .has-sidebar:not(.error404) #primary {
        width: auto;
        float: none;
    }
}
<?php
            }

            if (get_theme_mod('implement_yoast_breadcrumbs') && !is_front_page() && (is_single() || is_page())) {

                add_action('loop_start', array($this, 'ofts_implement_yoast_breadcrumbs'));

            }

            if (get_theme_mod('inject_featured_image_caption')) {

                add_filter('post_thumbnail_html', array($this, 'ofts_inject_featured_image_caption'), 10, 5);

?>
.post-thumbnail a img {
    display: block;
}

.post-thumbnail,
.single-featured-image-header {
	position: relative;
}

.post-thumbnail>a>div,
.single-featured-image-header>div {
	position: absolute;
	bottom: 1rem;
	left: 0;
	right: 0;
	z-index: 1;
}

.post-thumbnail>a>div>div,
.single-featured-image-header>div>div {
	font-size: 1.5rem;
	font-weight: 800;
	color: white;
	text-transform: uppercase;
}

@media screen and (min-width: 30em) {
    .post-thumbnail>a>div,
	.single-featured-image-header>div {
		bottom: 3rem;
	}
}

@media screen and (min-width: 48em) {
    .post-thumbnail>a>div>div,
	.single-featured-image-header>div>div {
		font-size: 2.25rem;
	}
}

.post-thumbnail:after,
.single-featured-image-header:after {
	/* Permalink - use to edit and share this gradient: http://colorzilla.com/gradient-editor/#000000+0,000000+100&0+0,0.3+75 */
	background: -moz-linear-gradient(to top, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.3) 75%, rgba(0, 0, 0, 0.3) 100%); /* FF3.6-15 */
	background: -webkit-linear-gradient(to top, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.3) 75%, rgba(0, 0, 0, 0.3) 100%); /* Chrome10-25,Safari5.1-6 */
	background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.3) 75%, rgba(0, 0, 0, 0.3) 100%); /* W3C, IE10+, FF16+, Chrome26+, Opera12+, Safari7+ */
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr="#00000000", endColorstr="#4d000000", GradientType=0); /* IE6-9 */
	bottom: 0;
	content: "";
	display: block;
	height: 100%;
	left: 0;
	position: absolute;
	right: 0;
}
<?php

            }

            oftsCommon::generate_css('.post-thumbnail>a>div>div, .single-featured-image-header>div>div', 'font-size', 'featured_image_caption_font_size', '', 'rem', get_theme_mod('featured_image_caption_font_size') / 1000);
            oftsCommon::generate_css('.post-thumbnail>a>div>div, .single-featured-image-header>div>div', 'font-weight', 'featured_image_caption_font_weight');

            if (get_theme_mod('move_featured_image')) {

                add_action('wp_footer', array($this, 'ofts_move_featured_image'));
?>
.single-featured-image-header {
    margin-bottom: 1em;
}
<?php
            }

            oftsCommon::generate_css('.archive .post .post-thumbnail', 'display', 'hide_archive_featured_images', '', '', 'none');
            oftsCommon::generate_css('.posted-on, .blog .entry-meta>a, .archive .entry-meta>a', 'display', 'remove_posted_on', '', '', 'none');

            if (get_theme_mod('remove_author')) {

                add_filter('gettext', array($this, 'ofts_replace_post_author_text'), 10, 3 );

            }

            if (get_theme_mod('remove_category_tag')) {

                add_filter('gettext', array($this, 'ofts_replace_archive_titles'), 10, 3 );

            }

            if (get_theme_mod('show_content_on_posts_page') && is_home() && get_option('page_for_posts')) {

                add_action('get_template_part_template-parts/header/site', array($this, 'ofts_show_content_on_posts_page'));

            }

            $mod = get_theme_mod('footer_background_image');

            if ($mod) {

?>
.site-footer {
background-image: url("<?= $mod; ?>");
background-size: cover;
background-position: center center;
}
<?php

            }

            if (get_theme_mod('footer_sidebars')) {

                add_action('get_template_part_template-parts/footer/footer', array($this, 'ofts_get_footer_sidebars'));

                if (get_theme_mod('footer_sidebars') == 3) {

?>
@media screen and (min-width: 48em) {
    .site-footer .widget-column.footer-widget-1, .site-footer .widget-column.footer-widget-2, .site-footer .widget-column.footer-widget-3 {
        float: left;
        width: 29.33333%;
    }
    .site-footer .widget-column.footer-widget-1, .site-footer .widget-column.footer-widget-2 {
        margin-right: 6%;
    }
}
<?php

                } else {

?>
@media screen and (min-width: 48em) {
    .site-footer .widget-column.footer-widget-1, .site-footer .widget-column.footer-widget-2, .site-footer .widget-column.footer-widget-3, .site-footer .widget-column.footer-widget-4 {
        float: left;
        width: 20.5%;
    }
    .site-footer .widget-column.footer-widget-1, .site-footer .widget-column.footer-widget-2, .site-footer .widget-column.footer-widget-3 {
        margin-right: 6%;
    }
}
<?php

                }

            }

            $mod = get_theme_mod('fix_social_links');

            if ($mod) {
?>
@media screen and (min-width: 48em) {
    footer .social-navigation {
        z-index: 1002;
        position: fixed;
        <?= $mod; ?>: 0;
        width: auto;
        transform: translate(0, -50%);
        top: 50vh;
        z-index: 7;
    }
    footer .social-navigation li {
    	display: block;
    }
    footer .social-navigation li a {
    	margin-<?= $mod; ?>: -20px;
    }
    footer .social-navigation ul {
    	transition: 0.25s padding ease-out;
    }
    footer .social-navigation ul:hover {
    	padding-<?= $mod; ?>: 36px;
    }
    .site-info {
        width: 100%;
    }
}
<?php
            }

            if (get_theme_mod('square_social_links')) {
?>
.social-navigation a {
    -webkit-border-radius: 0;
    border-radius: 0;
    height: 34px;
    width: 34px;
}
.social-navigation .icon {
    top: 9px;
}
<?php
            }

            if (get_theme_mod('colored_social_links_menu')) {

                add_action('get_template_part_template-parts/footer/site', array($this, 'ofts_colored_social_links_menu'));

            }

}

if (oftsPremium::request_permission(true) && get_theme_mod('footer_background_color') && get_theme_mod('footer_background_opacity')) {

    list($r, $g, $b) = sscanf(get_theme_mod('footer_background_color'), "#%02x%02x%02x");

?>
.site-footer {
    background-color: rgba(<?= $r; ?>, <?= $g; ?>, <?= $b; ?>, <?= (absint(get_theme_mod('footer_background_opacity')) - 1) / 10; ?> );
}
<?php

}

?>
</style> 
<!--/Customizer CSS-->
<?php

        }

        function ofts_hide_youtube_until_loaded() {

             if (is_front_page()) {

?>
<script type="text/javascript">
    if (jQuery('.twentyseventeen-front-page').length > 0 && jQuery(window).width() >= 900) {
    	var wp_custom_header_html = jQuery('#wp-custom-header').html();
    	var ww_timer = setTimeout(function ww_video() {
            if (typeof wp.customHeader == 'undefined') {
                ww_timer = setTimeout(ww_video, 50);
            } else if (typeof wp.customHeader.handlers == 'undefined') {
                ww_timer = setTimeout(ww_video, 50);
            } else if (wp.customHeader.handlers.youtube.player == null) {
    			ww_timer = setTimeout(ww_video, 50);
    			jQuery('#wp-custom-header').append(jQuery(wp_custom_header_html));
    		} else {
    			if (typeof wp.customHeader.handlers.youtube.player.getPlayerState === 'function') {
    				if (wp.customHeader.handlers.youtube.player.getPlayerState() == 1) {
    					jQuery('#wp-custom-header img').remove();
    				} else {
    					ww_timer = setTimeout(ww_video, 500);
    				}
    			} else {
    				if (jQuery("#wp-custom-header img").length == 0) {
    					jQuery('#wp-custom-header').append(jQuery(wp_custom_header_html));
    				}
    				ww_timer = setTimeout(ww_video, 50);
    			}
    		}
    	}, 50);
    }
</script>
<?php

             }

        }

        function ofts_pause_youtube_on_scroll() {

             if (is_front_page()) {

?>
<script type="text/javascript">
    if (jQuery('.twentyseventeen-front-page').length > 0 && jQuery(window).width() >= 900) {
    	jQuery(window).scroll(function(){
    	    if (jQuery(document).scrollTop() > 70 && wp.customHeader.handlers.youtube.player != null && typeof wp.customHeader.handlers.youtube.player.getPlayerState === 'function' && wp.customHeader.handlers.youtube.player.getPlayerState() == 1) {
    	      	wp.customHeader.handlers.youtube.player.pauseVideo();
    	    } else if (jQuery(document).scrollTop() < 71 && wp.customHeader.handlers.youtube.player != null && typeof wp.customHeader.handlers.youtube.player.getPlayerState === 'function' && wp.customHeader.handlers.youtube.player.getPlayerState() == 2) {
    	      	wp.customHeader.handlers.youtube.player.playVideo();
    	    }
    	});
    }
</script>
<?php

             }

        }

        function ofts_video_looping_off() {

             if (is_front_page()) {

?>
<script type="text/javascript">
    jQuery(document).ready( function() {
        jQuery(document).on('wp-custom-header-video-loaded', function() {
            jQuery("#wp-custom-header-video").attr('autoplay', false);
            jQuery("#wp-custom-header-video").attr('loop', false);
            document.getElementById('wp-custom-header-video').play();
        });
    });
</script>
<?php

             }

        }

        function ofts_inject_excerpt_post_thumbnails($slug, $name) {

        	if ($name == 'excerpt') {

        		if ('' !== get_the_post_thumbnail() && !is_single()) {

?>
<div class="post-thumbnail-<?= get_the_ID(); ?> post-thumbnail">
	<a href="<?php the_permalink(); ?>">
		<?php the_post_thumbnail( 'twentyseventeen-featured-image' ); ?>
	</a>
</div><!-- .post-thumbnail -->
<script type="text/javascript">
	jQuery(document).ready(function() {         
		jQuery(".post-thumbnail-<?= get_the_ID(); ?>").insertAfter("article.post-<?= get_the_ID(); ?> header");
	});
</script>
<?php

        		}

        	}

        }

        function ofts_inject_true_parallax() {

            global $post;

            if (is_page() && ((get_post_meta($post->ID, 'ofts_home_page_panels', true) == '1') || is_front_page())) {

            $parallax_speed = get_theme_mod('true_parallax_speed');

            if ($parallax_speed) { $parallax_speed = absint($parallax_speed) / 100; } else { $parallax_speed = 0.5; }

?>
<script type="text/javascript">
function ofts_true_parallax(){
	if (window.matchMedia('(min-width: 48em)').matches) {
		jQuery('.panel-image').each(function() {
		    var $element = jQuery(this);
		    if ((jQuery(window).scrollTop() + jQuery(window).innerHeight() > $element.offset().top) && (jQuery(window).scrollTop() < $element.offset().top + $element.outerHeight())) {
			    $element.css('backgroundPosition', '50% ' + Math.round(($element.offset().top - jQuery(window).scrollTop()) * <?= $parallax_speed; ?>) +  'px'); 
			}
		}); 
    }
};
jQuery(window).bind('scroll', ofts_true_parallax);
</script>
<?php

            }

        }

        function ofts_inject_footer_back_to_top() {

            if (!is_front_page() || (is_front_page() && !get_theme_mod('front_page_sections_back_to_top'))) {

?>
<p class="back-to-top back-to-top-footer"><a href="#page"><svg class="icon icon-arrow-right" aria-hidden="true" role="img"><use href="#icon-arrow-right" xlink:href="#icon-arrow-right"></use></svg><span class="screen-reader-text"><?= __('Back to top', 'options-for-twenty-seventeen'); ?></span></a></p>
<script type="text/javascript">
    jQuery(document).ready(function() {
        jQuery(".back-to-top-footer").appendTo(jQuery("#main"));
    });
</script>
<?php

            }

        }

        function ofts_inject_front_page_sections_to_back_to_top($slug, $name) {

            if ($name == 'front-page-panels' || $name == 'front-page') {

                global $post;

?>
<script type="text/javascript">
    jQuery(document).ready(function() {
        jQuery(".back-to-top-<?= $post->post_name; ?>").appendTo(jQuery(".back-to-top-<?= $post->post_name; ?>").next().find(".recent-posts"));
        jQuery(".back-to-top-<?= $post->post_name; ?>").appendTo(jQuery(".back-to-top-<?= $post->post_name; ?>").next().find(".panel-content .entry-content"));
    });
</script>
<p class="back-to-top back-to-top-<?= $post->post_name; ?>"><a href="#main"><svg class="icon icon-arrow-right" aria-hidden="true" role="img"><use href="#icon-arrow-right" xlink:href="#icon-arrow-right"></use></svg><span class="screen-reader-text"><?= __('Back to top', 'options-for-twenty-seventeen'); ?></span></a></p>
<?php

            }

        }

        function ofts_inject_header_true_parallax() {

            if (is_page() or is_single()) {

            $parallax_speed = get_theme_mod('true_parallax_speed');

            if ($parallax_speed) { $parallax_speed = absint($parallax_speed) / 100; } else { $parallax_speed = 0.5; }

?>
<script type="text/javascript">
function ofts_header_true_parallax(){
	if (window.matchMedia('(min-width: 48em)').matches) {
		var $imageElement = jQuery('.has-header-image .custom-header-media img');
		var $iframeElement = jQuery('.has-header-image .custom-header-media iframe');
		var $headerElement = jQuery('header');
		if ((jQuery(window).scrollTop() + jQuery(window).innerHeight() > $headerElement.offset().top) && (jQuery(window).scrollTop() < $headerElement.offset().top + $headerElement.outerHeight())) {
			$imageElement.css('objectPosition', '50% ' + Math.round(($headerElement.offset().top - jQuery(window).scrollTop()) * <?= $parallax_speed; ?>) +  'px');
			$iframeElement.css('objectPosition', '50% ' + Math.round((0 - jQuery(window).scrollTop()) * <?= $parallax_speed; ?>) +  'px');
		}
    }
};
jQuery(window).bind('scroll', ofts_header_true_parallax);
</script>
<?php

            }

        }

        function ofts_auto_excerpt($content) {

            global $more;

            if (get_post_type() == 'post' && $more === 0 && strpos($content, 'class="more-link"') === false) {

                if (get_theme_mod('auto_excerpt_words')) { $excerpt_words = absint(get_theme_mod('auto_excerpt_words'));} else { $excerpt_words = 55;}

                $text = get_the_content('');
                $text = strip_shortcodes($text);
                $text = str_replace(']]>', ']]&gt;', $text);
                $excerpt_length = apply_filters('excerpt_length', $excerpt_words);
                $excerpt_more = apply_filters('excerpt_more', ' ' . '[&hellip;]');
                $text = wp_trim_words($text, $excerpt_length, $excerpt_more);
                $content = apply_filters('wp_trim_excerpt', $text, '');

                if (strpos($content, 'class="more-link"') === false) {

                    $post = get_post();
                    $more_link_text = __('Continue reading', 'options-for-twenty-seventeen') . '<span class="screen-reader-text">' . $post->post_title . '</span>';
                    $content .= apply_filters( 'the_content_more_link', '<p class="link-more"><a href="' . get_permalink() . "#more-{$post->ID}\" class=\"more-link\">$more_link_text</a></p>", $more_link_text );

                }

            }

            return $content;

        }

        function ofts_reset_tag_cloud_args($args) {

        	$args['largest']  = 22;
        	$args['smallest'] = 8;
        	$args['unit']     = 'pt';
        	$args['format']   = 'flat';

        	return $args;

        }

        function ofts_featured_header_image() {

?>
<script type="text/javascript">
    if (jQuery('.single-featured-image-header img').length > 0) {
        if (typeof(jQuery('.single-featured-image-header img').data('lazy-src')) != 'undefined') {
            jQuery('.wp-custom-header img').attr('src', jQuery('.single-featured-image-header img').data('lazy-src'));
            jQuery('.wp-custom-header img').attr('srcset', '');
            jQuery('.single-featured-image-header').remove();
            jQuery('body').addClass('has-featured-image');
        } else if (typeof(jQuery('.single-featured-image-header img').attr('src')) != 'undefined') {
            jQuery('.wp-custom-header img').attr('src', jQuery('.single-featured-image-header img').attr('src'));
            if (typeof(jQuery('.single-featured-image-header img').attr('srcset')) != 'undefined') {
                jQuery('.wp-custom-header img').attr('srcset', jQuery('.single-featured-image-header img').attr('srcset'));
            } else {
                jQuery('.wp-custom-header img').attr('srcset', '');
            }
            jQuery('.single-featured-image-header').remove();
            jQuery('body').addClass('has-featured-image');
        }
    }
</script>
<?php

        }

        function ofts_get_header_sidebar() {

		    if (is_active_sidebar('header')) {

                echo('<div class="wrap header-sidebar-wrap"><div id="header-sidebar" class="' . get_theme_mod('header_sidebar') . '">');
                dynamic_sidebar('header');
                echo('</div></div>');

		    }

        }

        function ofts_nivo_slider() {

            $slider_post_type = get_post_type(get_theme_mod('nivo_slider_cover'));

            if ($slider_post_type == 'nivoslider' && function_exists('nivo_slider')) {

?>
<div class="custom-header-media">
    <div id="wp-custom-header" class="wp-custom-header">
<?php nivo_slider(get_theme_mod('nivo_slider_cover')); ?>
    </div><?php

                if (get_theme_mod('enable_nivo_captions')) {
?>
<script type="text/javascript">
jQuery(document).ready(function() {
  	jQuery('.nivoSlider').each(function() {
		jQuery(this).find('a').each(function() {
			jQuery(jQuery(this).find('img').attr('title')).wrapInner("<a href='" + jQuery(this).attr("href") + "'></a>");
		});
	});
});
</script><?php
                }

?>
</div>
<?php

            } elseif ($slider_post_type == 'wpspaios_slider' && function_exists('wp_spaios_slider_shortcode')) {

?>
<div class="custom-header-media">
    <div id="wp-custom-header" class="wp-custom-header">
<?php echo wp_spaios_slider_shortcode(array(
                    'id' => get_theme_mod('nivo_slider_cover')
                )); ?>
    </div>
</div>
<?php

            } elseif ($slider_post_type == 'ml-slider' && class_exists('MetaSliderPlugin')) {

?>
<div class="custom-header-media">
    <div id="wp-custom-header" class="wp-custom-header">
<?php echo do_shortcode('[metaslider id="' . get_theme_mod('nivo_slider_cover') . '"]'); ?>
    </div>
</div>
<?php

            } elseif ($slider_post_type == 'smoothslides' && class_exists('smoothslides_class')) {

?>
<div class="custom-header-media">
    <div id="wp-custom-header" class="wp-custom-header">
<?php echo do_shortcode('[smoothslides id="' . get_theme_mod('nivo_slider_cover') . '" effect="panLeft" pagination="false" navigation="false" effectduration=5000 transitionduration=1000]'); ?>
    </div>
</div>
<?php

            }

        }

        function ofts_header_image_body_class($classes) {

		    $classes[] = 'has-header-image';
            return $classes;

        }

        function ofts_add_logo_to_nav() {

            $mod = get_theme_mod('add_logo_to_nav');

?>
<script type="text/javascript">

jQuery(document).ready(function() {
<?php if (get_theme_mod('nav_logo_align') == 'center') { ?>
jQuery('#site-navigation .menu-item:nth-child(' + Math.ceil(jQuery('#site-navigation .menu-item').length / 2) + ')').after(jQuery('.site-branding .custom-logo-link')<?= ($mod == 'copy' ? '.clone()' : ''); ?>);
jQuery('#site-navigation .custom-logo-link').wrap('<li class="menu-item"></li>');
<?php } else { ?>
    jQuery('.site-branding .custom-logo-link')<?= ($mod == 'copy' ? '.clone()' : ''); ?>.prependTo(jQuery('#site-navigation'));
<?php } ?>
<?php if (((get_theme_mod('animate_nav_logo') == 'home' && is_front_page()) || get_theme_mod('animate_nav_logo') == 'all')) { ?>jQuery('#site-navigation .custom-logo-link img').data('size','big');
if (jQuery('#site-navigation .custom-logo-link img').attr('width') > 350) {
    jQuery('#site-navigation .custom-logo-link img').data('height',parseInt(jQuery('#site-navigation .custom-logo-link img').attr('height') / jQuery('#site-navigation .custom-logo-link img').attr('width') * 350) + 'px');
} else {
    jQuery('#site-navigation .custom-logo-link img').data('height',jQuery('#site-navigation .custom-logo-link img').attr('height') + 'px');
}
jQuery(window).scroll(function(){
    if (jQuery(window).width() > 959 && jQuery(document).scrollTop() > 70) {
        if (jQuery('#site-navigation .custom-logo-link img').data('size') == 'big') {
          	jQuery('#site-navigation .custom-logo-link img').data('size','small');
            jQuery('#site-navigation .custom-logo-link img').stop().animate({
                height: '49px'
            },300);
        }
    } else if (jQuery(window).width() > 959) {
        if (jQuery('#site-navigation .custom-logo-link img').data('size') == 'small') {
          	jQuery('#site-navigation .custom-logo-link img').data('size','big');
            jQuery('#site-navigation .custom-logo-link img').stop().animate({
                height: jQuery('#site-navigation .custom-logo-link img').data('height')
            },300);
        }
    }
});<?php } ?>
});

</script>
<?php

        }

        function ofts_check_nav_height() {

?>
<script type="text/javascript">
    function customHeaderHeight() {
        if (window.matchMedia('(min-width: 48em)').matches) {
            jQuery(".custom-header").css('margin-top',jQuery(".navigation-top").outerHeight()+'px');
        } else {
            jQuery(".custom-header").css('margin-top','0');
        }
    }
    jQuery(document).ready(function() {
        customHeaderHeight();
    });
    jQuery(window).resize(function(){
        customHeaderHeight();
    });
</script>
<?php

        }

        function ofts_match_primary_secondary_height() {

?>
<script type="text/javascript">
    jQuery(window).bind('load', function() {
        if (jQuery(window).width() > 767) {
            if (jQuery('#primary').innerHeight() > jQuery('#secondary').innerHeight()) {
	            jQuery('#secondary').innerHeight(jQuery('#primary').innerHeight());
	        } else {
	            jQuery('#primary').innerHeight(jQuery('#secondary').innerHeight());
	        }
        }
	} );
</script>
<?php

        }

        function ofts_implement_yoast_breadcrumbs() {

            if (function_exists('yoast_breadcrumb')) {

                yoast_breadcrumb('<p id="breadcrumbs">','</p>');

?>
<script type="text/javascript">
    jQuery(document).ready(function() {<?php

                if (get_theme_mod('implement_yoast_breadcrumbs') == 'top' || get_theme_mod('implement_yoast_breadcrumbs') == 'both') {

?>
        jQuery("#main>#breadcrumbs").clone().prependTo(jQuery(".entry-content"));<?php

                }

                if (get_theme_mod('implement_yoast_breadcrumbs') == 'bottom' || get_theme_mod('implement_yoast_breadcrumbs') == 'both') {

?>        
        jQuery("#main>#breadcrumbs").clone().appendTo(jQuery(".entry-content"));<?php

                }

?>
        jQuery("#main>#breadcrumbs").remove();
    });
</script>
<?php

            }

        }

        function ofts_inject_featured_image_caption($html, $post_id, $post_thumbnail_id, $size, $attr) {

        	$caption = wp_get_attachment_caption($post_thumbnail_id);

        	if ($caption) {

        		$html = $html . '<div class="wrap"><div>' . $caption . '</div></div>';

            }
    
        	return $html;

        }

        function ofts_move_featured_image() {

            if (is_single()) {
?>
<script type="text/javascript">
    jQuery(document).ready(function() {
        jQuery(".single-featured-image-header").prependTo(jQuery("#primary #main .entry-content"));
    });
</script>
<?php
            }

        }

        function ofts_replace_post_author_text($translation, $text, $domain) {
 
            if ($text === 'by %s' && $domain == 'twentyseventeen') {

                $translation = '';

            }

            return $translation;

        }

        function ofts_replace_archive_titles($translation, $text, $domain) {
 
            if ($text === 'Category: %s') {

                $translation = '%s';

            }

            if ($text === 'Tag: %s') {

                $translation = '%s';

            }

            return $translation;

        }

        function ofts_show_content_on_posts_page() {

?>
	<div class="taxonomy-description">
		<?php
			echo(apply_filters('the_content', get_post_field('post_content', get_option('page_for_posts'))));
		?>
	</div><!-- .entry-content -->
<script type="text/javascript">
    jQuery(document).ready(function() {
        jQuery(".taxonomy-description").prependTo(jQuery(".site-main"));
    });
</script>
<?php

        }

        function ofts_get_footer_sidebars() {

		    if (is_active_sidebar('footer-3')) {

?>
<div class="widget-column footer-widget-3">
<?php dynamic_sidebar('footer-3'); ?>
</div>
<script type="text/javascript">
    jQuery(document).ready(function() {
        jQuery(".footer-widget-3").appendTo(jQuery("footer .widget-area"));
    });
</script>
<?php

            }

		    if (is_active_sidebar('footer-4')) {

?>
<div class="widget-column footer-widget-4">
<?php dynamic_sidebar('footer-4'); ?>
</div>
<script type="text/javascript">
    jQuery(document).ready(function() {
        jQuery(".footer-widget-4").appendTo(jQuery("footer .widget-area"));
    });
</script>
<?php

            }

        }

        function ofts_colored_social_links_menu() {
?>
<script type="text/javascript">
    jQuery(document).ready(function() {
        var socialColors = {
            behance: '#1769ff',
            deviantart: '#05cc47',
            digg: '#005be2',
            dockerhub: '#0db7ed',
            dribbble: '#000000',
            dropbox: '#007ee5',
            facebook: '#3b5998',
            flickr: '#ff0084',
            foursquare: '#0072b1',
            'google-plus': '#dd4b39',
            github: '#000000',
            instagram: '#e95950',
            linkedin: '#007bb5',
            medium: '#00ab6c',
            'pinterest-p': '#cb2027',
            periscope: '#3aa4c6',
            'get-pocket': '#ef4056',
            'reddit-alien': '#ff4500',
            skype: '#00aff0',
            slideshare: '#0077b5',
            'snapchat-ghost': '#fffc00',
            soundcloud: '#ff8800',
            spotify: '#00e461',
            stumbleupon: '#eb4924',
            tumblr: '#32506d',
            twitch: '#6441A4',
            twitter: '#55acee',
            vimeo: '#aad450',
            vine: '#00bf8f',
            vk: '#45668e',
            wordpress: '#21759b',
            yelp: '#af0606',
            youtube: '#ff0000'
        };
        jQuery.each(socialColors, function(key, value) {
            jQuery('.icon-' + key).parent().css('background-color', value);
            jQuery('.icon-' + key).parent().hover(function(){jQuery(this).css('background-color', shadeColor(value, -0.3));},function(){jQuery(this).css('background-color', value);});
        });
    });
    function shadeColor(color, percent) {   
        var f=parseInt(color.slice(1),16),t=percent<0?0:255,p=percent<0?percent*-1:percent,R=f>>16,G=f>>8&0x00FF,B=f&0x0000FF;
        return "#"+(0x1000000+(Math.round((t-R)*p)+R)*0x10000+(Math.round((t-G)*p)+G)*0x100+(Math.round((t-B)*p)+B)).toString(16).slice(1);
    }
</script>
<?php
        }

        function ofts_front_page_sections($num_sections) {

            return absint(get_theme_mod('front_page_sections'));

        }

        function ofts_front_page_sections_add_menu_meta_box($object) {

            add_meta_box('custom-menu-metabox', __('Front Page Sections', 'options-for-twenty-seventeen'), array($this, 'ofts_front_page_sections_menu_meta_box'), 'nav-menus', 'side', 'default');

            return $object;

        }

        function ofts_front_page_sections_menu_meta_box() {

        	global $nav_menu_selected_id;

        	$walker = new Walker_Nav_Menu_Checklist();
        	$current_tab = 'all';
            $front_page_sections = array();
        	$num_sections = apply_filters('twentyseventeen_front_page_sections', 4);

        	for ($i = 1; $i < (1 + $num_sections); $i++) {

            	if (get_theme_mod('panel_' . $i)) {

            		$post = get_post(get_theme_mod('panel_' . $i));

                    $front_page_sections[] = (object) array(
                        'classes' => array(),
                        'type' => 'custom',
                        'object_id' => $i,
                        'title' => $post->post_title,
                        'object' => 'custom',
                        'url' => trailingslashit(home_url()) . '#' . $this->ofts_check_static_front_page_id($post->post_name),
                        'attr_title' => $post->post_title,
                        'db_id' => 0,
                        'menu_item_parent' => 0,
                        'target' => '',
                        'xfn' => ''
                    );

            	}

        	}

        	$removed_args = array( 'action', 'customlink-tab', 'edit-menu-item', 'menu-item', 'page-tab', '_wpnonce' );

?>
	<div id="sectionarchive" class="categorydiv">

		<ul id="sectionarchive-tabs" class="sectionarchive-tabs add-menu-item-tabs">
			<li <?php echo ( 'all' == $current_tab ? ' class="tabs"' : '' ); ?>>
				<a class="nav-tab-link" data-type="tabs-panel-sectionarchive-all" href="<?php if ( $nav_menu_selected_id ) echo esc_url( add_query_arg( 'sectionarchive-tab', 'all', remove_query_arg( $removed_args ) ) ); ?>#tabs-panel-sectionarchive-all">
					<?php _e('View All', 'options-for-twenty-seventeen'); ?>
				</a>
			</li><!-- /.tabs -->
		</ul>

		<div id="tabs-panel-sectionarchive-all" class="tabs-panel tabs-panel-view-all <?php echo ( 'all' == $current_tab ? 'tabs-panel-active' : 'tabs-panel-inactive' ); ?>">
			<ul id="sectionarchive-checklist-all" class="categorychecklist form-no-clear">
			<?php
				echo walk_nav_menu_tree( array_map('wp_setup_nav_menu_item', $front_page_sections), 0, (object) array( 'walker' => $walker) );
			?>
			</ul>
		</div><!-- /.tabs-panel -->

		<p class="button-controls wp-clearfix">
			<span class="list-controls">
				<a href="<?php echo esc_url( add_query_arg( array( 'sectionarchive-tab' => 'all', 'selectall' => 1, ), remove_query_arg( $removed_args ) )); ?>#sectionarchive" class="select-all"><?php _e('Select All', 'options-for-twenty-seventeen'); ?></a>
			</span>
			<span class="add-to-menu">
				<input type="submit"<?php wp_nav_menu_disabled_check( $nav_menu_selected_id ); ?> class="button-secondary submit-add-to-menu right" value="<?php esc_attr_e('Add to Menu', 'options-for-twenty-seventeen'); ?>" name="add-sectionarchive-menu-item" id="submit-sectionarchive" />
				<span class="spinner"></span>
			</span>
		</p>

	</div><!-- /.categorydiv -->
<?php

        }

        function ofts_inject_ids_to_front_page_sections() {

            if (is_front_page() && !is_home()) {

?>
<script type="text/javascript">
<?php
        	$num_sections = apply_filters('twentyseventeen_front_page_sections', 4);

        	for ($i = 1; $i < (1 + $num_sections); $i++) {

            	$post = get_post(get_theme_mod('panel_' . $i));
                $panel_id = $this->ofts_check_static_front_page_id($post->post_name);

?>
    jQuery("#panel<?= $i; ?> .panel-content").attr('id', '<?= $panel_id; ?>');
<?php

                if (get_post_meta($post->ID, 'ofts_hide_title', true) == '1') {

?>
    jQuery("#panel<?= $i; ?> .panel-content header").hide();
<?php

                }

        	}
?>
</script>
<?php

            }

        }

        function ofts_footer_sidebars_init() {

            if (get_theme_mod('footer_sidebars')) {

    	        register_sidebar( array(
            		'name'          => __( 'Footer 3', 'options-for-twenty-seventeen' ),
            		'id'            => 'footer-3',
            		'description'   => __( 'Add widgets here to appear in your footer.', 'twentyseventeen' ),
            		'before_widget' => '<section id="%1$s" class="widget %2$s">',
            		'after_widget'  => '</section>',
            		'before_title'  => '<h2 class="widget-title">',
            		'after_title'   => '</h2>',
            	) );

            }

            if (get_theme_mod('footer_sidebars') && get_theme_mod('footer_sidebars') == '4') {

    	        register_sidebar( array(
            		'name'          => __( 'Footer 4', 'options-for-twenty-seventeen' ),
            		'id'            => 'footer-4',
            		'description'   => __( 'Add widgets here to appear in your footer.', 'twentyseventeen' ),
            		'before_widget' => '<section id="%1$s" class="widget %2$s">',
            		'after_widget'  => '</section>',
            		'before_title'  => '<h2 class="widget-title">',
            		'after_title'   => '</h2>',
            	) );

            }

        }

        function ofts_hide_featured_image($html, $post_id, $post_thumbnail_id, $size, $attr) {

            if (!$post_id) {

                return $html;

            } elseif (get_post_meta($post_id, 'ofts_hide_featured_image', true) == '1' && (is_page() || is_single())) {

                return;

            } else {

                return $html;

            }

        }

        function ofts_home_page_panels() {

            global $post;

            if (is_page() && get_post_meta($post->ID, 'ofts_home_page_panels', true) == '1') {

                $args = array(
                	'post_parent' => $post->ID,
                	'post_type'   => 'page',
                	'post_status' => 'publish',
                	'orderby'     => 'menu_order',
                    'order' => 'ASC'
                );
                $children = get_children($args);
                global $twentyseventeencounter;

    			foreach ($children as $child_id => $child) {

                    $post = get_post($child_id);
            		setup_postdata($post);
            		set_query_var('panel', $child_id);
            		$twentyseventeencounter = $child_id;
            		get_template_part( 'template-parts/page/content', 'front-page-panels' );

?>

<script type="text/javascript">
<?php

                    $panel_id = $this->ofts_check_static_front_page_id($post->post_name);

?>
    jQuery("#panel<?= $child_id; ?> .panel-content").attr('id', '<?= $panel_id; ?>');
<?php

                    if (get_post_meta($post->ID, 'ofts_hide_title', true) == '1') {

?>
    jQuery("#panel<?= $child_id; ?> .panel-content header").hide();
<?php

                    }

?>
</script>
<?php
            		wp_reset_postdata();

    			}

            }

        }

        function ofts_check_static_front_page_id($post_name) {

            $panel_id = $post_name;
            $id_cannot_be = array(
                'page',
                'masthead',
                'site-navigation',
                'top-menu',
                'content',
                'primary',
                'main',
                'secondary',
                'colophon',
                'wpadminbar',
                'wp-toolbar'
            );
            $id_cannot_start_with = array('wp-admin-bar-',
                'adminbar',
                'icon-',
                'menu-item-',
                'post-',
                'panel');
            $id_cannot_end_with = array(
                '-css'
            );

            if (in_array($post_name, $id_cannot_be)) {

                $panel_id = 'panel-' . $post_name;

            }

            foreach ($id_cannot_start_with as $id_start) {

                if (stripos($post_name, $id_start) === 0) {

                    $panel_id = 'panel-' . $post_name;

                }

            }

            foreach ($id_cannot_end_with as $id_end) {

                if (stripos(strrev($post_name), strrev($id_end)) === 0) {

                    $panel_id = 'panel-' . $post_name;

                }

            }

            return $panel_id;

        }

        function ofts_theme_options_metabox_setup() {

            add_action('add_meta_boxes', array($this, 'ofts_add_theme_options_metabox'));

            if (oftsPremium::request_permission()) {

                add_action('save_post', array($this, 'ofts_save_theme_options_meta'), 10, 2);

            }

        }

        function ofts_add_theme_options_metabox() {

            add_meta_box('ofts_meta_box', __('Theme Options', 'options-for-twenty-seventeen'), array($this, 'ofts_render_theme_options_metabox'), array('post', 'page'), 'side');

        }

        function ofts_render_theme_options_metabox($post) {

            $upgrade_link = '<a href="' . oftsCommon::upgrade_link() . '" title="' . __('Upgrade Options for Twenty Seventeen', 'options-for-twenty-seventeen') . '">' . __('Upgrade Options for Twenty Seventeen', 'options-for-twenty-seventeen') . '</a>';

            if (get_option('ofts_purchased') == false) {

                if (get_option('ofts_trial_date') && time() < (strtotime('+1 week', get_option('ofts_trial_date')))) {

                    $expiring_in = ceil(abs((strtotime('+1 week', get_option('ofts_trial_date'))) - time())/60/60/24);
                    $expiring_text = '<p><span class="attention">' . sprintf(_n('Options for Twenty Seventeen plugin trial expires in less than %s day!', 'Options for Twenty Seventeen plugin trial expires in less than %s days!', $expiring_in, 'options-for-twenty-seventeen'), $expiring_in) . '</span>';
                    echo('<strong>' . $expiring_text . '</strong>' . ' ' . $upgrade_link . ' ' . __('to keep using all the options after that time.', 'options-for-twenty-seventeen') . '</p>');

                }

            }

            wp_nonce_field('options-for-twenty-seventeen', 'ofts-meta-nonce');

            if (oftsPremium::request_permission()) {

?>
<input type="checkbox" name="ofts-hide-featured-image" id="ofts-hide-featured-image" value="1" <?php checked(get_post_meta($post->ID, 'ofts_hide_featured_image', true), '1' ); ?> />
<label for="ofts-hide-featured-image"><?= __('Hide featured image', 'options-for-twenty-seventeen'); ?></label><?php

                if ($post->post_type == 'post' || ($post->post_type == 'page' && get_theme_mod('page_sidebar'))) {

?>
<br />
<input type="checkbox" name="ofts-hide-page-sidebar" id="ofts-hide-page-sidebar" value="1" <?php checked(get_post_meta($post->ID, 'ofts_hide_page_sidebar', true), '1' ); ?> />
<label for="ofts-hide-page-sidebar"><?= __('Hide sidebar', 'options-for-twenty-seventeen'); ?></label>

<?php

                }

                if ($post->post_type == 'page') {

?>
<br />
<input type="checkbox" name="ofts-home-page-panels" id="ofts-home-page-panels" value="1" <?php checked(get_post_meta($post->ID, 'ofts_home_page_panels', true), '1' ); ?> />
<label for="ofts-home-page-panels"><?= __('Show child pages as panels', 'options-for-twenty-seventeen'); ?></label>

<?php

                }

?>
<br />
<input type="checkbox" name="ofts-hide-title" id="ofts-hide-title" value="1" <?php checked(get_post_meta($post->ID, 'ofts_hide_title', true), '1' ); ?> />
<label for="ofts-hide-title"><?= __('Hide title', 'options-for-twenty-seventeen'); ?></label>

<?php

            } else {

?>

<p><?= $upgrade_link; ?> <?= __('to hide featured images on single posts and pages, hide the sidebar on pages, show child pages as panels and hide titles.', 'options-for-twenty-seventeen'); ?></p>

<?php
            }

        }

        function ofts_save_theme_options_meta($post_id, $post) {

            if (!isset( $_POST['ofts-meta-nonce'] ) || !wp_verify_nonce($_POST['ofts-meta-nonce'], 'options-for-twenty-seventeen')) {

                return;

            }

            $post_type = get_post_type_object( $post->post_type );

            if (!current_user_can($post_type->cap->edit_post, $post_id)) {

                return;

            }

            if (isset($_POST['ofts-hide-featured-image']) && $_POST['ofts-hide-featured-image'] == '1') {

                update_post_meta($post_id, 'ofts_hide_featured_image', 1);

            } else {

                delete_post_meta($post_id, 'ofts_hide_featured_image');

            }

            if (isset($_POST['ofts-hide-page-sidebar']) && $_POST['ofts-hide-page-sidebar'] == '1') {

                update_post_meta($post_id, 'ofts_hide_page_sidebar', 1);

            } else {

                delete_post_meta($post_id, 'ofts_hide_page_sidebar');

            }

            if (isset($_POST['ofts-home-page-panels']) && $_POST['ofts-home-page-panels'] == '1') {

                update_post_meta($post_id, 'ofts_home_page_panels', 1);

            } else {

                delete_post_meta($post_id, 'ofts_home_page_panels');

            }

            if (isset($_POST['ofts-hide-title']) && $_POST['ofts-hide-title'] == '1') {

                update_post_meta($post_id, 'ofts_hide_title', 1);

            } else {

                delete_post_meta($post_id, 'ofts_hide_title');

            }

        }

        function ofts_social_links_icons($social_links_icons) {

            return array_merge($social_links_icons, array(
                'amazon.com' => 'amazon',
                'bookbub.com' => 'bookbub',
                'goodreads.com' => 'goodreads'
            ));

        }

        function ofts_include_svg_icons() {

            $svg_icons = dirname(__FILE__) . '/images/svg-icons.svg';

        	if (file_exists( $svg_icons)) {

                require_once $svg_icons;

            }

        }

	}

    if (!class_exists('oftsPremium')) {

        require_once(dirname(__FILE__) . '/includes/class-ofts-premium.php');

    }

    function options_for_twenty_seventeen_premium_init() {

        if (class_exists('options_for_twenty_seventeen_class') && class_exists('oftsCommon')) {

            oftsPremium::start_trial();
            $options_for_twenty_seventeen_premium_object = new options_for_twenty_seventeen_premium_class();

        } else {

            add_action('admin_notices', 'oftsPremium::free_plugin_notice');

        }

    }

    add_action('plugins_loaded', 'options_for_twenty_seventeen_premium_init');

}

?>
